% Steffensen's method to accelerate convergence of certain fixed point iterations
% Inputs
%  g	 contraction (function taking a real argument and returning a real
%        number) 
%  x0    initial iterate
%  maxit maximum number of iterations 
%        (each Steffensen iteration costs two evaluations of g)
%  tol   tolerance for two consecutive iterates
% 
% Outputs
%  xs    vector containing the iterates
function xs = steffensen(g,x0,maxit,tol);
 % TO BE COMPLETED
